Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(768)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 1817693002: Support edge-inclusive intersections in mapToVisibleRectInAncestorSpace (Closed) Base URL: https://chromium.googlesource.com/chromium/src@intersection-observer-idle-callback
Patch Set: Address comments, add mapToVisibleRectInContainerSpace test Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index 387058354128dc2e7c11ef76bba0ec84dd51844c..cb9080d264dad196f81074bdd3fdd411fa64a80b 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -1146,9 +1146,15 @@ public:
virtual LayoutRect clippedOverflowRectForPaintInvalidation(const LayoutBoxModelObject* paintInvalidationContainer, const PaintInvalidationState* = nullptr) const;
// Given a rect in the object's coordinate space, compute a rect in the coordinate space of |ancestor|. If
- // intermediate containers have clipping or scrolling of any kind, it is applied; but overflow clipping is *not*
- // applied for |ancestor| itself. The output rect is suitable for purposes such as paint invalidation.
- virtual void mapToVisibleRectInAncestorSpace(const LayoutBoxModelObject* ancestor, LayoutRect&, const PaintInvalidationState*) const;
+ // intermediate containers have clipping or scrolling of any kind, it is applied; but overflow clipping is
+ // *not* applied for |ancestor| itself. The output rect is suitable for purposes such as paint invalidation.
+ //
+ // If visibleRectFlags is EdgeInclusive, clipping operations will use LayoutRect::inclusiveIntersect,
chrishtr 2016/03/22 19:54:26 s/is/has/
szager1 2016/03/23 23:26:59 Done.
+ // and the return value of inclusiveIntersect will be propagated to the return value of this method.
+ // Otherwise, clipping operations will use LayoutRect::intersect, and the return value will be true
+ // only if the clipped rect has non-zero area. See the documentation for LayoutRect::inclusiveIntersect
+ // for more information.
+ virtual bool mapToVisibleRectInAncestorSpace(const LayoutBoxModelObject* ancestor, LayoutRect&, const PaintInvalidationState*, VisibleRectFlags = DefaultVisibleRectFlags) const;
// Return the offset to the column in which the specified point (in flow-thread coordinates)
// lives. This is used to convert a flow-thread point to a visual point.

Powered by Google App Engine
This is Rietveld 408576698